/* Copyright (C) 2023 Physikalisches Institut, Eberhard Karls Universitaet Tuebingen, Tuebingen
   SPDX-License-Identifier: GPL-3.0-only
   Authors: Lukas Chlad [committer] */

#ifndef CBMFSDDETECTORMAPMANAGER_H
#define CBMFSDDETECTORMAPMANAGER_H

#include <RtypesCore.h>  // for Int_t, Double_t

#include <iostream>  // for string
#include <map>       // for map
#include <vector>    // for vector

struct CbmFsdModuleData;

class CbmFsdDetectorMapManager {

private:
  /** Default constructor **/
  CbmFsdDetectorMapManager();

  /** Default destructor **/
  ~CbmFsdDetectorMapManager();

public:
  CbmFsdDetectorMapManager(const CbmFsdDetectorMapManager&) = delete;
  CbmFsdDetectorMapManager& operator=(const CbmFsdDetectorMapManager&) = delete;

  /**
	 * Return Instance of CbmFsdDetectorMapManager.
	 */
  static CbmFsdDetectorMapManager& GetInstance()
  {
    static CbmFsdDetectorMapManager fInstance;
    return fInstance;
  }

  /*
	 * \brief Return digi moduleId by path to node.
	 */
  Int_t GetModuleIdByPath(const std::string& path);

  /*
	 * \brief Return CbmFsdModuleData by digi moduleId.
	 */
  CbmFsdModuleData* GetModuleDataById(Int_t id);

  /*
     * \brief Return ids of all modules
     */
  std::vector<Int_t> GetModuleIds();

private:
  std::map<std::string, Int_t> fModulePathToIdMap;
  std::map<Int_t, CbmFsdModuleData*> fModuleIdToDataMap;
  std::vector<Int_t> fModuleIds;  // vector of all  module ids

  /*
	 * \brief Initialize maps.
	 */
  void Init();
};

#endif /* CBMFSDDETECTORMAPMANAGER_H */
